summaryrefslogtreecommitdiffstats
path: root/korganizer/actionmanager.h
diff options
context:
space:
mode:
Diffstat (limited to 'korganizer/actionmanager.h')
-rw-r--r--korganizer/actionmanager.h130
1 files changed, 65 insertions, 65 deletions
diff --git a/korganizer/actionmanager.h b/korganizer/actionmanager.h
index b8c9cadb..f19f7b4b 100644
--- a/korganizer/actionmanager.h
+++ b/korganizer/actionmanager.h
@@ -27,7 +27,7 @@
#ifndef KORG_ACTIONMANAGER_H
#define KORG_ACTIONMANAGER_H
-#include <qobject.h>
+#include <tqobject.h>
#include <kurl.h>
#include <korganizer/part.h>
#include <kdepimmacros.h>
@@ -71,12 +71,12 @@ using namespace KCal;
actions are in one location.
It also provides DCOP interface[s].
*/
-class KDE_EXPORT ActionManager : public QObject, public KCalendarIface
+class KDE_EXPORT ActionManager : public TQObject, public KCalendarIface
{
Q_OBJECT
public:
ActionManager( KXMLGUIClient *client, CalendarView *widget,
- QObject *parent, KOrg::MainWindow *mainWindow,
+ TQObject *parent, KOrg::MainWindow *mainWindow,
bool isPart );
virtual ~ActionManager();
@@ -130,90 +130,90 @@ class KDE_EXPORT ActionManager : public QObject, public KCalendarIface
/** Is there a instance with this URL? */
static KOrg::MainWindow* findInstance( const KURL &url );
/** Open calendar file from URL */
- bool openURL( const QString &url );
+ bool openURL( const TQString &url );
/** Open calendar file from URL */
- bool mergeURL( const QString &url );
+ bool mergeURL( const TQString &url );
/** Save calendar file to URL */
- bool saveAsURL( const QString &url );
+ bool saveAsURL( const TQString &url );
/** Close calendar file opened from URL */
void closeURL();
- /** Get current URL as QString */
- QString getCurrentURLasString() const;
+ /** Get current URL as TQString */
+ TQString getCurrentURLasString() const;
/**
Delete the incidence with the given unique id from current calendar.
@param uid UID of the incidence to delete.
@param force If true, all recurrences and sub-todos (if applicable) will be
deleted without prompting for confirmation.
*/
- virtual bool deleteIncidence( const QString& uid, bool force = false );
+ virtual bool deleteIncidence( const TQString& uid, bool force = false );
- bool editIncidence( const QString& uid );
+ bool editIncidence( const TQString& uid );
/**
Add an incidence to the active calendar.
@param ical A calendar in iCalendar format containing the incidence.
*/
- bool addIncidence( const QString& ical );
+ bool addIncidence( const TQString& ical );
//// Implementation of the DCOP interface
- virtual ResourceRequestReply resourceRequest( const QValueList<QPair<QDateTime, QDateTime> >& busy,
- const QCString& resource,
- const QString& vCalIn );
-
- void openEventEditor( const QString& );
- void openEventEditor( const QString& summary,
- const QString& description,
- const QString& attachment );
- void openEventEditor( const QString& summary,
- const QString& description,
- const QString& attachment,
- const QStringList& attendees );
- void openEventEditor( const QString& summary,
- const QString& description,
- const QString& uri,
- const QString& file,
- const QStringList& attendees,
- const QString& attachmentMimetype );
-
- void openTodoEditor( const QString& );
- void openTodoEditor( const QString& summary,
- const QString& description,
- const QString& attachment );
- void openTodoEditor( const QString& summary,
- const QString& description,
- const QString& attachment,
- const QStringList& attendees );
- void openTodoEditor( const QString& summary,
- const QString& description,
- const QString& uri,
- const QString& file,
- const QStringList& attendees,
- const QString& attachmentMimetype );
-
- void openJournalEditor( const QDate& date );
- void openJournalEditor( const QString& text, const QDate& date );
- void openJournalEditor( const QString& text );
+ virtual ResourceRequestReply resourceRequest( const TQValueList<QPair<TQDateTime, TQDateTime> >& busy,
+ const TQCString& resource,
+ const TQString& vCalIn );
+
+ void openEventEditor( const TQString& );
+ void openEventEditor( const TQString& summary,
+ const TQString& description,
+ const TQString& attachment );
+ void openEventEditor( const TQString& summary,
+ const TQString& description,
+ const TQString& attachment,
+ const TQStringList& attendees );
+ void openEventEditor( const TQString& summary,
+ const TQString& description,
+ const TQString& uri,
+ const TQString& file,
+ const TQStringList& attendees,
+ const TQString& attachmentMimetype );
+
+ void openTodoEditor( const TQString& );
+ void openTodoEditor( const TQString& summary,
+ const TQString& description,
+ const TQString& attachment );
+ void openTodoEditor( const TQString& summary,
+ const TQString& description,
+ const TQString& attachment,
+ const TQStringList& attendees );
+ void openTodoEditor( const TQString& summary,
+ const TQString& description,
+ const TQString& uri,
+ const TQString& file,
+ const TQStringList& attendees,
+ const TQString& attachmentMimetype );
+
+ void openJournalEditor( const TQDate& date );
+ void openJournalEditor( const TQString& text, const TQDate& date );
+ void openJournalEditor( const TQString& text );
//TODO:
// void openJournalEditor( const QString& summary,
// const QString& description,
// const QString& attachment );
void showJournalView();
void showTodoView();
void showEventView();
- void goDate( const QDate& );
- void goDate( const QString& );
- void showDate( const QDate &date );
+ void goDate( const TQDate& );
+ void goDate( const TQString& );
+ void showDate( const TQDate &date );
- QString localFileName();
+ TQString localFileName();
bool queryClose();
- void loadProfile( const QString & path );
+ void loadProfile( const TQString & path );
- void saveToProfile( const QString & path ) const;
+ void saveToProfile( const TQString & path ) const;
signals:
/**
@@ -333,9 +333,9 @@ class KDE_EXPORT ActionManager : public QObject, public KCalendarIface
void setTitle();
- void updateUndoAction( const QString & );
+ void updateUndoAction( const TQString & );
- void updateRedoAction( const QString & );
+ void updateRedoAction( const TQString & );
void slotImportDialogFinished( ImportDialog * );
@@ -350,10 +350,10 @@ class KDE_EXPORT ActionManager : public QObject, public KCalendarIface
/**
Return widget used as parent for dialogs and message boxes.
*/
- QWidget *dialogParent();
+ TQWidget *dialogParent();
private slots:
- void dumpText( const QString & ); // only for debugging purposes
+ void dumpText( const TQString & ); // only for debugging purposes
private:
class ActionStringsVisitor;
@@ -364,12 +364,12 @@ class KDE_EXPORT ActionManager : public QObject, public KCalendarIface
KOrg::Part::List mParts; // List of parts loaded
KURL mURL; // URL of calendar file
- QString mFile; // Local name of calendar file
- QString mLastUrl; // URL of last loaded calendar.
+ TQString mFile; // Local name of calendar file
+ TQString mLastUrl; // URL of last loaded calendar.
KTempFile *mTempFile;
- QTimer *mAutoSaveTimer; // used if calendar is to be autosaved
- QTimer *mAutoArchiveTimer; // used for the auto-archiving feature
+ TQTimer *mAutoSaveTimer; // used if calendar is to be autosaved
+ TQTimer *mAutoArchiveTimer; // used for the auto-archiving feature
// list of all existing KOrganizer instances
static KOWindowList *mWindowList;
@@ -130,90 +130,90 @@ class KDE_EXPORT ActionManager : public QObject, public KCalendarIface
//TODO:
- // void openJournalEditor( const QString& summary,
- // const QString& description,
- // const QString& attachment );
+ // void openJournalEditor( const TQString& summary,
+ // const TQString& description,
+ // const TQString& attachment );
void showJournalView();
void showTodoView();